@@ -90,8 +90,8 @@ warnings (L<https://rt.cpan.org/Public/Bug/Display.html?id=97977>)
 
 package ODF::lpOD_Helper;
 
-our $VERSION = '3.005'; # VERSION
-our $DATE = '2023-04-02'; # DATE
+our $VERSION = '3.006'; # VERSION
+our $DATE = '2023-04-05'; # DATE
 
 our @EXPORT = qw(
   __disconnected_style
@@ -1282,6 +1282,10 @@ sub fmt_match(_) { # sans final newline
   my $href = shift;
   return "undef" unless defined $href;
   my %h = %$href;
+  if ( (any {! defined($h{$_})} qw/match segments offset end voffset vend/)
+       || ref($h{segments}) ne "ARRAY") {
+    confess "INVALID MATCH STRUCTURE:\n",vis($href)
+  }
   my @segments = map {
                   my $t = __element2vtext($_);
                   "$_ ".vis("$t")." (len=".length($t).")"
